#' @name PaulinoEx12.3
#' @title Associação de nistagmo e vertigem do sistema vestibular 
#'     conforme período de estimulação.
#' @description Um estudo realizado no Hospital das Clínicas da Faculdade 
#'     de Medicina de Ribeirão Preto da Universidade de São Paulo cujo 
#'     objetivo era avaliar a associação entre duas respostas (nistagmo 
#'     e vertigem) do sistema vestibular (responsável pela sensação de 
#'     equilíbrio dos seres humanos). Considera-se a a aobservação do 
#'     nistagmo e da vertigem em três ocasiões: no início, durante e 
#'     após a estimulação do sistema vestibular.
#' @format Um \code{data.frame} com 27 observações e 4 variáveis.
#'
#' \describe{
#'
#' \item{\code{idv}}{Intensidade da vertigem (ausente, fraca/moderada e forte).}
#'
#' \item{\code{idn}}{Intensidade do nistagmo (ausente, fraca/moderada e forte).}
#'
#' \item{\code{per}}{Período de estimulação (inicial, intermediário e final).}
#' 
#' \item{\code{freq}}{Frequência no período inicial, intermediário e final.}
#' 
#' }
#' @keywords TC
#' @source PAULINO; SINGER (2006), Tabela 12.3, pág. 447.
#' @examples
#' 
#' library(lattice)
#' data(PaulinoEx12.3) 
#' 
#' dados <- xtabs(freq ~ per + idn + idv, data = PaulinoEx12.3)
#' barchart(dados, horizontal = FALSE, 
#'     stack = FALSE,
#'     ylab = "Frequência",
#'     main = "Associação de nistagmo e vertigem do sistema vestibular 
#'     conforme período de estimulação",
#'     auto.key = list(corner = c(0.99, 0.88), 
#'     text = c("Ausente", "Forte", "Fraca-moderada")))
#' 
#'
NULL
