#' @name PaulinoTb12.5
#' @title Sensibilidade dentaria pre e pos-operatoria.
#' @description Um estudo realizado pela Faculdade de Odontologia da 
#'     Universidade de Mogi das Cruzes, SP, teve como objetivo avaliar 
#'     o efeito de dois adesivos dentários (Single Bond) e (Prime bond 
#'     NT) e de duas condições de aplicação (dentina seca ou húmida) na 
#'     variação (pré e pós-operatória) da sensibilidade dentinária 
#'     (presente ou ausente) de pacientes submetidos a um certo tipo de 
#'     tratamento odontológico. 
#' @format Um \code{data.frame} com 16 observações e 5 variáveis.
#'
#' \describe{
#'
#' \item{\code{mat}}{Material utilizado no estudo. Neste caso os adesivos
#'     single bond e prime bond.}
#'
#' \item{\code{den}}{Condições de aplicação da dentina (seca ou húmida).}
#'
#' \item{\code{speo}}{Sensibilidade pré-operatória.}
#' 
#' \item{\code{spso}}{Sensibilidade pós-operatória.}
#' 
#' \item{\code{freq}}{Frequência com os valores observados.}
#' }
#' @keywords TC
#' @source PAULINO; SINGER (2006), Tabela 12.5, pág. 422.
#' @references Singer, J. M. e Polli, D. a. (2004). Avaliação clínica de 
#'     dois adesivos dentários 18 meses após aplicação em dentina seca 
#'     ou úmida, Relatório de análise estatística CEA-RAE-04P12, Centro 
#'     de Estatística Aplicada, IME, Universidade de São Paulo.
#' @examples
#' 
#' library(lattice)
#' data(PaulinoTb12.5) 
#' 
#' dados <- xtabs(freq ~ speo + den + mat + spso, data = PaulinoTb12.5)
#' barchart(dados, horizontal = FALSE, 
#'     stack = FALSE,
#'     ylab = "Frequência",
#'     main = "Sensibilidade dentária pré e pós-operatória.",
#'     auto.key = list(corner = c(0.99, 0.88), 
#'     text = c("Ausente", "Presente")))
#' 
#'
NULL
