#' @name PaulinoTb13.14
#' @title Frequencias observadas na sondagem de opiniao na Eslovenia.
#' @description Os resultados referem-se a um inquérito de opinião na 
#'     Eslovénia antes do referendo do 1990 que viria a conduzir a sua 
#'     independência, retirados de Rubin, Stern e Vehovar (1995). Dizem 
#'     respeito as respostas dadas as perguntas: é a favor da secessão 
#'     eslovena da Jugoslávia? Tenciona votar no referendo? É a favor da 
#'     independência da Eslovénia? O objetivo principal do inquérito 
#'     consistiu em estimar a proporção da população que tencionaria 
#'     votar no referendo a favor da independência.
#' @format Um \code{data.frame} com 27 observações e 4 variáveis.
#'
#' \describe{
#'
#' \item{\code{seca}}{Secessão A. Refere-se a pergunta feita: é a favor 
#'    da secessão eslovena da Jugoslávia?}
#'
#' \item{\code{refb}}{Referendo B. Refere-se a pergunta feita:Tenciona 
#'     votar no referendo?}
#'
#' \item{\code{indep}}{Independência. Refere-se a pergunta: é a favor da 
#'     independência da Eslovénia?}
#' 
#' \item{\code{freq}}{Frequência relaionando os valores.}
#' }
#' @keywords TC
#' @source PAULINO; SINGER (2006), Tabela 13.14, pág. 485.
#' @references Rubin, D. B., Stern, H. S. e Vehovar, V. (1995). Handling 
#'     "Don't know" survey responses, Journal of American Statistical 
#'     Association 69:467-474.
#' @examples
#' 
#' library(lattice)
#' data(PaulinoTb13.14)
#' 
#' dados <- xtabs(freq ~ refb + seca + indep, data = PaulinoTb13.14)
#' barchart(dados, horizontal = FALSE, 
#'     stack = FALSE,
#'     scales = list(x = list(labels = c("sim","não", "omisso"))),
#'     ylab = "Frequência",
#'     xlab = "Grupos",
#'     main = "Frequências observadas na sondagem de opinião na Eslovénia.",
#'     auto.key = list(corner = c(0.90, 0.95), 
#'     text = c("omisso", "não", "sim")))
#' 
#'
NULL
